pub struct TableField {
pub name: &'static str,
pub is_primary_key: bool,
pub is_unique: bool,
pub foreign_key_to_table_name: Option<&'static str>,
pub sql_type_name: &'static str,
pub is_null: bool,
}Expand description
Information about a field of a table struct.
Fields
name: &'static strThe name of the field.
is_primary_key: boolIs this field the primary key?
is_unique: boolDoes this field have a unique constraint on it?
foreign_key_to_table_name: Option<&'static str>The name of the table which this field has a foreign key constraint to, if any.
sql_type_name: &'static strThe sql string representation of this field’s sql type.
is_null: boolIs this field nullable?