SummableSqlExpression

Trait SummableSqlExpression 

pub trait SummableSqlExpression<S: SelectableTables>: SqlExpression<S>
where Self::SqlType: SummableSqlType,
{ // Provided method fn sum(self) -> SqlSum<S, Self> { ... } }
An sql expression which is summable, which means that we can sum the values of it.

Provided Methods

fn sum(self) -> SqlSum<S, Self>

Returns an expression which evaluates to the sum of the items returned from the query.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors