pub trait FilterUpdateStatement: UpdateStatement<HasWhereClause = TypedFalse> {
// Provided method
fn filter<C: SqlExpression<Self::UpdateTable, SqlType = SqlBool>>(
self,
condition: C,
) -> UpdateWithWhereClause<Self, C> { ... }
}Expand description
A trait which allows filtering an update statement so that it only updates records matching some condition.
Provided Methods
Sourcefn filter<C: SqlExpression<Self::UpdateTable, SqlType = SqlBool>>(
self,
condition: C,
) -> UpdateWithWhereClause<Self, C>
fn filter<C: SqlExpression<Self::UpdateTable, SqlType = SqlBool>>( self, condition: C, ) -> UpdateWithWhereClause<Self, C>
Filters this update statement, so that it only updates records which match the given condition.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.